==> payara-embedded-all-4.1.1.171-sources.jar: com/sun/enterprise/security/jauth/callback/CertStoreCallback.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 1997-2011 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package com.sun.enterprise.security.jauth.callback;

import java.security.KeyStore;
import java.security.cert.CertStore;
import javax.security.auth.callback.Callback;

/**
 * Callback for CertStore.
 *
 * <p> A CertStore is a generic repository for certificates.
 * CertStores may be searched to locate public key certificates,
 * as well as to put together certificate chains.
 * Such a search may be necessary when the caller needs to
 * verify a signature.
 *
 * @version %I%, %G%
 */
public class CertStoreCallback extends
        javax.security.auth.message.callback.CertStoreCallback {

    /**
     * Set the CertStore.
     *
     * @param certStore the certificate store, which may be null
     *		If null, the requester is assumed to already have
     *		access to the relevant certificate and/or chain.
     */
    public void setStore(CertStore certStore) {
	setCertStore(certStore);
    }
}

==> payara-embedded-all-6.2023.10-sources.jar: com/sun/enterprise/security/jauth/callback/CertStoreCallback.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 1997-2011 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package com.sun.enterprise.security.jauth.callback;

import java.security.KeyStore;
import java.security.cert.CertStore;
import javax.security.auth.callback.Callback;

/**
 * Callback for CertStore.
 *
 * <p> A CertStore is a generic repository for certificates.
 * CertStores may be searched to locate public key certificates,
 * as well as to put together certificate chains.
 * Such a search may be necessary when the caller needs to
 * verify a signature.
 *
 * @version %I%, %G%
 */
public class CertStoreCallback extends
        jakarta.security.auth.message.callback.CertStoreCallback {

    /**
     * Set the CertStore.
     *
     * @param certStore the certificate store, which may be null
     *		If null, the requester is assumed to already have
     *		access to the relevant certificate and/or chain.
     */
    public void setStore(CertStore certStore) {
	setCertStore(certStore);
    }
}
